aboutsummaryrefslogtreecommitdiffstats
path: root/src/vlib/node.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/vlib/node.h')
-rw-r--r--src/vlib/node.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/vlib/node.h b/src/vlib/node.h
index f7155aeda86..6b9a2df95d3 100644
--- a/src/vlib/node.h
+++ b/src/vlib/node.h
@@ -116,6 +116,7 @@ typedef struct _vlib_node_registration
/* Error strings indexed by error code for this node. */
char **error_strings;
+ vl_counter_t *error_counters;
/* Buffer format/unformat for this node. */
format_function_t *format_buffer;
@@ -323,8 +324,8 @@ typedef struct vlib_node_t
u32 error_heap_handle;
u32 error_heap_index;
- /* Error strings indexed by error code for this node. */
- char **error_strings;
+ /* Counter structures indexed by counter code for this node. */
+ vl_counter_t *error_counters;
/* Vector of next node names.
Only used before next_nodes array is initialized. */